Skip to content

Compare complex R objects and reveal the key differences. Designed particularly for use in testing packages where being able to quickly isolate key differences makes understanding test failures much easier.

Author

Maintainer: Hadley Wickham hadley@posit.co

Other contributors:

  • Posit Software, PBC [copyright holder, funder]